pub struct Asset {
pub access_level: Option<GoogleIdentityAccesscontextmanagerV1AccessLevel>,
pub access_policy: Option<GoogleIdentityAccesscontextmanagerV1AccessPolicy>,
pub asset_type: Option<String>,
pub iam_policy: Option<Policy>,
pub name: Option<String>,
pub org_policy: Option<Vec<GoogleCloudOrgpolicyV1Policy>>,
pub resource: Option<Resource>,
pub service_perimeter: Option<GoogleIdentityAccesscontextmanagerV1ServicePerimeter>,
}Expand description
An asset in Google Cloud. An asset can be any resource in the Google Cloud resource hierarchy, a resource outside the Google Cloud resource hierarchy (such as Google Kubernetes Engine clusters and objects), or a policy (e.g. IAM policy). See Supported asset types for more information.
This type is not used in any activity, and only used as part of another schema.
Fields
access_level: Option<GoogleIdentityAccesscontextmanagerV1AccessLevel>Please also refer to the access level user guide.
access_policy: Option<GoogleIdentityAccesscontextmanagerV1AccessPolicy>Please also refer to the access policy user guide.
asset_type: Option<String>The type of the asset. Example: compute.googleapis.com/Disk See Supported asset types for more information.
iam_policy: Option<Policy>A representation of the IAM policy set on a Google Cloud resource. There can be a maximum of one IAM policy set on any given resource. In addition, IAM policies inherit their granted access scope from any policies set on parent resources in the resource hierarchy. Therefore, the effectively policy is the union of both the policy set on this resource and each policy set on all of the resource’s ancestry resource levels in the hierarchy. See this topic for more information.
name: Option<String>The full name of the asset. Example: //compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1 See Resource names for more information.
org_policy: Option<Vec<GoogleCloudOrgpolicyV1Policy>>A representation of an organization policy. There can be more than one organization policy with different constraints set on a given resource.
resource: Option<Resource>A representation of the resource.
service_perimeter: Option<GoogleIdentityAccesscontextmanagerV1ServicePerimeter>Please also refer to the service perimeter user guide.