Struct google_cloudasset1_beta1::api::ExportAssetsRequest [−][src]
Export asset request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- export assets folders (request)
- export assets organizations (request)
- export assets projects (request)
Fields
asset_types: Option<Vec<String>>A list of asset types of which to take a snapshot for. For example: “google.compute.Disk”. If specified, only matching assets will be returned. See Introduction to Cloud Asset Inventory for all supported asset types.
content_type: Option<String>Asset content type. If not specified, no content but the asset name will be returned.
output_config: Option<OutputConfig>Required. Output configuration indicating where the results will be output to. All results will be in newline delimited JSON format.
read_time: Option<String>Timestamp to take an asset snapshot. This can only be set to a timestamp between 2018-10-02 UTC (inclusive) and the current time. If not specified, the current time will be used. Due to delays in resource data collection and indexing, there is a volatile window during which running the same query may get different results.